@@ -106,6 +106,10 @@ class AsyncoreConnection(pika.connection.Connection):
         if self.dispatcher:
             self.dispatcher.close()
 
+    def flush_outbound(self):
+        while self.outbound_buffer:
+            self.drain_events()
+
     def drain_events(self, timeout=None):
         loop(count = 1, timeout = timeout)
 
@@ -121,8 +125,12 @@ def next_event_timeout(default_timeout=None):
     cutoff = run_timers_internal()
     if timer_heap:
         timeout = timer_heap[0][0] - cutoff
+        if default_timeout is not None and timeout > default_timeout:
+            timeout = default_timeout
+    elif default_timeout is None:
+        timeout = 30.0 # default timeout
     else:
-        timeout = default_timeout or 30.0   #default timeout
+        timeout = default_timeout
     return timeout
 
 def log_timer_error(info):
